@@ -303,7 +303,8 @@ int rcv_pop (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 		{
 			/* If cannot assign the channel, then disconnect. */
 			sprintf (buf, "-ERR FBB POP3 server at %s - No free channel!\r\n", mycall);
-			write (new, buf, strlen (buf));
+			if (write (new, buf, strlen (buf)) == -1)
+				perror("rcv_pop() socket write error");
 			close (new);
 		}
 		else
@@ -320,8 +321,9 @@ int rcv_pop (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 				getpid(), time(NULL), mypath);
 			sprintf (buf, "+OK FBB POP3 server ready %s\r\n", 
 				tport[*port].tcan[i].md5string);
-			write (new, buf, strlen (buf));
-
+			if (write (new, buf, strlen (buf)) == -1)
+				perror("rcv_pop() socket write error");
+			
 			val = p_port[*port].pk_t;
 
 			return (FALSE);
@@ -359,7 +361,8 @@ int rcv_pop (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 		{
 			/* If cannot assign the channel, then disconnects. */
 			sprintf (buf, "421 FBB SMTP server at %s - No free channel!\r\n", mypath);
-			write (new, buf, strlen (buf));
+			if (write (new, buf, strlen (buf)) == -1)
+				perror("rcv_pop() socket write error");
 			close (new);
 		}
 		else
@@ -375,7 +378,8 @@ int rcv_pop (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 
 /* 			sprintf (buf, "220 FBB SMTP server ready at %s\r\n", mypath); */
 			sprintf (buf, "220 FBB ESMTP server ready at %s\r\n", mypath);
-			write (new, buf, strlen (buf));
+			if (write (new, buf, strlen (buf)) == -1)
+				perror("rcv_pop() socket write error");
 
 			val = p_port[*port].pk_t;
 
@@ -413,7 +417,8 @@ int rcv_pop (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 		{
 			/* If cannot assign the channel, then disconnect. */
 			sprintf (buf, "400 FBB NNTP server at %s - No free channel!\r\n", mypath);
-			write (new, buf, strlen (buf));
+			if (write (new, buf, strlen (buf)) == -1)
+				perror("rcv_pop() socket write error");
 			close (new);
 		}
 		else
@@ -428,7 +433,8 @@ int rcv_pop (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 
 
 			sprintf (buf, "201 FBB NNTP server ready at %s\r\n", mypath);
-			write (new, buf, strlen (buf));
+			if (write (new, buf, strlen (buf)) == -1)
+				perror("rcv_pop() socket write error");
 
 			val = p_port[*port].pk_t;
 
@@ -1545,7 +1551,8 @@ static int pop_send(int port, int canal, char *fmt, ...)
 		//if (1) I think it's best not to touch encoding.  Firefox can read and send 850 if needed.  This conversion just causes things to break
 		//		ibm_to_ansi(buf, strlen(buf));
 				
-		write (tport[port].tcan[canal].sock, buf, strlen (buf));
+		if (write (tport[port].tcan[canal].sock, buf, strlen (buf)) == -1)
+			perror("pop_send() socket write error");
 		free(buf);	
 		return 1;
 	}
@@ -2294,9 +2301,10 @@ static int smtp_reply(int port, int can, int next, int num, char *fmt, ...)
 		vsprintf (buf+nb, fmt, argptr);
 		va_end (argptr);
 
-		strcat(buf, "\r\n");	
-		write (tport[port].tcan[can].sock, buf, strlen (buf));
-		
+		strcat(buf, "\r\n");
+		if (write (tport[port].tcan[can].sock, buf, strlen (buf)) == -1)
+			perror("rcv_pop() socket write error");
+
 		return 1;
 	}
 	return 0;
@@ -2485,7 +2493,7 @@ static int smtp_rcv_dt(int port, int can, char *buffer, int len)
 			}
 			else
 			{
-				snprintf(str, sizeof(str)-1, "From: %s\r", tport[port].tcan[can].mail_from->address);
+				snprintf(str, sizeof(str)-1, "SMTP mail received, may be 3rd party mail.\rHeaders:\rFrom: %s\r", tport[port].tcan[can].mail_from->address);
 				str[sizeof(str)-1] = 0;
 				add_to_msg(port, can, str);
 			
