@@ -1,28 +1,24 @@
-   /****************************************************************
+/************************************************************************
     Copyright (C) 1986-2000 by
 
     F6FBB - Jean-Paul ROUBELAT
-    31120 - Roquettes - France
-	jpr@f6fbb.org
+    jpr@f6fbb.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
     Parts of code have been taken from many other softwares.
     Thanks for the help.
-    ****************************************************************/
-
+************************************************************************/
 #define ENGLISH
 
 #include <stdio.h>
@@ -44,7 +40,7 @@
 #endif
 
 #include <fbb_conf.h>
-#include "version.h"
+#include <config.h> 
 
 #define DEBUG   1
 #define TRUE    1
@@ -171,6 +167,7 @@ void init_liste (char *, int);
 void message_retour (int, bullist *, long);
 void newname (char *, char *);
 void print_compte_rendu (void);
+void print_zone(void);
 
 char *date_mbl_new (long);
 char *strdt (long);
@@ -232,15 +229,18 @@ char *back2slash (char *str)
 
 char *test_back_slash (char *chaine)
 {
-	if ((strlen(chaine) == 0)
+	static char temp[256];
+	strcpy(temp, chaine);
+
+	if ((strlen(temp) == 0)
 #ifdef __linux__
-		|| (chaine[strlen (chaine) - 1] != '/'))
-			strcat(chaine, "/");
+		|| (temp[strlen (temp) - 1] != '/'))
+			strcat(temp, "/");
 #else
-		|| (chaine[strlen (chaine) - 1] != '\\'))
-			strcat(chaine, "\\");
+		|| (temp[strlen (temp) - 1] != '\\'))
+			strcat(temp, "\\");
 #endif
-	return (chaine);
+	return (temp);
 }
 
 void err_keyword(char *keyword)
@@ -306,7 +306,7 @@ int main (int ac, char **av)
 	for (i = 0; i < NB_AUTOMESS; i++)
 		auto_mess[i] = 0;
 
-	printf ("Epurmess V %d.%02d\n\n", MAJEUR, MINEUR);
+	printf ("Epurmess V%s\n\n", VERSION);
 
 	for (i = 1; i < ac; i++)
 	{
@@ -427,7 +427,7 @@ int main (int ac, char **av)
 		exit (1);
 	}
 	record = 1L;
-	strcpy (mycall, entete.exped);
+	strncpy (mycall, entete.exped, sizeof (mycall));
 
 	while (1)
 	{
@@ -1012,6 +1012,15 @@ char *strdt (long temps)
 	return (cdate);
 }
 
+void print_zone()
+{
+  char *tz;
+      printf( "TZ: %s ", (tz = getenv( "TZ" )) ? tz : "not set" );
+      printf( "-  daylight: %d ", daylight );
+      printf( "-  timezone: %ld ", timezone );
+      printf( "-  time zone names: %s %s\n",
+      tzname[0], tzname[1] );
+}
 
 void defauts (void)
 {
@@ -1032,7 +1041,7 @@ void defauts (void)
 	str     = (char *) (calloc(80 , sizeof(char)));
 	tzlig   = (char *) (calloc(80 , sizeof(char)));
 	temp    = (char *) (calloc(20 , sizeof(char)));
-	
+
 	if (read_fbb_conf(NULL) > 0)
 	{
 #ifdef ENGLISH
@@ -1054,7 +1063,7 @@ void defauts (void)
 #endif
 		exit (1);
 	}
-	sprintf (temp, "FBB%d.%02d", MAJEUR, MINEUR);
+	sprintf (temp, "FBB%s", VERSION);
 
 	/* Only test the major number ... */
 	if (strncasecmp (temp, ptr, 4) != 0)
@@ -1066,7 +1075,11 @@ void defauts (void)
 #endif
 		exit (1);
 	}
-	fprintf (stderr, "Configuration version : %s\r\n", ptr);
+#ifdef __linux__
+	fprintf (stderr, "Configuration version : %s\n", ptr);
+#else
+	fprintf (stderr, "Configuration version : %s\r", ptr);
+#endif
 
 	ptr = find_fbb_conf("call", 0);
 	if (ptr == NULL)
@@ -1130,16 +1143,12 @@ void defauts (void)
 	if (ptr == NULL)
 		err_keyword("loca");
 #ifdef ENGLISH
-	fprintf (stderr, "GMT difference : %d\n", atoi (ptr));
+	fprintf (stderr, "GMT difference : %d - ", atoi (ptr));
 #else
-	fprintf (stderr, "Diffrence GMT : %d\n", atoi (ptr));
+	fprintf (stderr, "Diffrence GMT : %d - ", atoi (ptr));
 #endif
-	if (getenv ("TZ") == NULL)
-	{
-		sprintf (tzlig, "TZ=XXX%d", -atoi (ptr));
-		putenv (tzlig);
-	}
 	tzset ();		/* get timezone info */
+	print_zone();
 
 	putchar ('\n');
 	sleep (2);
@@ -1311,7 +1320,7 @@ void defauts (void)
 #ifdef ENGLISH
 		fprintf (stderr, "Cannot open EPURMESS.INI file       \n");
 #else
-		fprintf (stderr, "Error ouverture fichier EPURMESS.INI\n");
+		fprintf (stderr, "Erreur ouverture fichier EPURMESS.INI\n");
 #endif
 
 		exit (1);
