@@ -1,34 +1,31 @@
-   /****************************************************************
+/************************************************************************
     Copyright (C) 1986-2000 by
 
     F6FBB - Jean-Paul ROUBELAT
-    6, rue George Sand
-    31120 - Roquettes - France
-	jpr@f6fbb.org
+    jpr@f6fbb.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
     Parts of code have been taken from many other softwares.
     Thanks for the help.
-    ****************************************************************/
+************************************************************************/
 
 /*
  *    MODULE FORWARDING OVERLAY 2
  */
 
 #include <serv.h>
+#include <config.h>
 
 static int tst_line (char *, int);
 static int tst_var (char *);
@@ -43,10 +40,17 @@ char *idnt_fwd (void)
 	*ptr++ = 'B';
 	*ptr++ = 'B';
 	*ptr++ = '-';
-	*ptr++ = '0' + MAJEUR;
+	*ptr++ = '0' + PACKAGE_VERSION_MAJOR;
 	*ptr++ = '.';
-	*ptr++ = '0' + MINEUR / 10;
-	*ptr++ = '0' + MINEUR % 10;
+	*ptr++ = '0' + PACKAGE_VERSION_MINOR;
+	*ptr++ = '.';
+	//*ptr++ = '0' + PACKAGE_VERSION_MICRO;
+	if (PACKAGE_VERSION_MICRO < 10) {
+		*ptr++ = '0' + PACKAGE_VERSION_MICRO;
+	} else if (PACKAGE_VERSION_MICRO < 100) {
+		*ptr++ = '0' + (PACKAGE_VERSION_MICRO / 10);
+		*ptr++ = '0' + (PACKAGE_VERSION_MICRO % 10);
+	}
 	*ptr++ = '-';
 	*ptr++ = 'A';
 	if (pvoie->prot_fwd & FWD_FBB)
