@@ -1,28 +1,24 @@
-   /****************************************************************
+/************************************************************************
     Copyright (C) 1986-2000 by
 
     F6FBB - Jean-Paul ROUBELAT
-    6, rue George Sand
-    31120 - Roquettes - France
-	jpr@f6fbb.org
+    jpr@f6fbb.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
     Parts of code have been taken from many other softwares.
     Thanks for the help.
-    ****************************************************************/
+************************************************************************/
 
 /*
  *
@@ -783,7 +779,7 @@ int incindd (void)
 }
 
 
-void selvoie (voie)
+void selvoie (int voie)
 {
 	/* static int    cv = -1; */
 	/* static Svoie  curr; */
@@ -804,7 +800,7 @@ void selvoie (voie)
 	}
 	else
 		fbb_error (ERR_CANAL, "Select channel", voie);
-
+	
 	ff ();
 }
 
@@ -954,7 +950,7 @@ char *c_disque (char *chaine)
 	return (sup_ln (s));
 }
 
-void test_disque ()
+void test_disque (void)
 {
 #if defined(__WINDOWS__) || defined(__FBBDOS__)
 	char texte[300];
