@@ -1,28 +1,24 @@
-   /****************************************************************
+/************************************************************************
     Copyright (C) 1986-2000 by
 
     F6FBB - Jean-Paul ROUBELAT
-    6, rue George Sand
-    31120 - Roquettes - France
-	jpr@f6fbb.org
+    jpr@f6fbb.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
     Parts of code have been taken from many other softwares.
     Thanks for the help.
-    ****************************************************************/
+************************************************************************/
 
 /*
  *    MODULE TNC.C : INTERFACE AVEC LE TNC - MODE DUPLEX
@@ -171,8 +167,10 @@ void duplex_tnc (void)
 			texte (T_GAT + 1);
 		}
 		else
-		{
-			noport = *indd - '0';
+		{				
+			//noport = *indd - '0';					
+			noport = atoi(indd);		
+			
 			if ((voiecur != CONSOLE) && (noport == no_port (voiecur)))
 			{
 				texte (T_GAT + 6);
@@ -281,7 +279,7 @@ void duplex_tnc (void)
 					texte (T_GAT + 5);
 					ch_niv3 (3);
 					return;
-				case 'P':
+				case 'P':					
 					save_voie = voiecur;
 					pvoie->ch_mon = -1;
 					selvoie (pvoie->cross_connect);
@@ -501,7 +499,8 @@ void duplex_tnc (void)
 					outs (buffer, nb);
 					break;
 				case 'J':
-					j_list ((char) no_port (pvoie->cross_connect) + '0');
+					//j_list ((char) no_port (pvoie->cross_connect) + '0');
+					j_list (no_port (pvoie->cross_connect), 0);
 					break;
 				case 'M':
 					if (pvoie->ch_mon == -1)
@@ -516,7 +515,7 @@ void duplex_tnc (void)
 					}
 					outln (s, strlen (s));
 					break;
-				case 'P':
+				case 'P':					
 					save_voie = voiecur;
 					pvoie->ch_mon = -1;
 					selvoie (pvoie->cross_connect);
@@ -649,7 +648,7 @@ void duplex_tnc (void)
 #ifdef ENGLISH
 							sprintf (buffer, "Yapp receiving %s ...", indd);
 #else
-							sprintf (buffer, "Yapp reoit %s ...   ", indd);
+							sprintf (buffer, "Yapp reçoit %s ...   ", indd);
 #endif
 #ifdef __FBBDOS__
 							trait (0, buffer);
@@ -962,7 +961,7 @@ void duplex_tnc (void)
 #ifdef ENGLISH
 							sprintf (buffer, "Yapp receiving %s ...", indd);
 #else
-							sprintf (buffer, "Yapp reoit %s ...   ", indd);
+							sprintf (buffer, "Yapp reçoit %s ...   ", indd);
 #endif
 #ifdef __FBBDOS__
 							trait (0, buffer);
@@ -1061,7 +1060,7 @@ void duplex_tnc (void)
 #ifdef ENGLISH
 			sprintf (buffer, "Transfer aborted");
 #else
-			sprintf (buffer, "Transfert arrt");
+			sprintf (buffer, "Transfert arrêté");
 #endif
 #ifdef __FBBDOS__
 			trait (-1, buffer);
@@ -1078,7 +1077,7 @@ void duplex_tnc (void)
 #ifdef ENGLISH
 			sprintf (buffer, "Transfer aborted");
 #else
-			sprintf (buffer, "Transfert arrt");
+			sprintf (buffer, "Transfert arrêté");
 #endif
 #ifdef __FBBDOS__
 			trait (-1, buffer);
